@@ -27,18 +27,19 @@
 function sl_get_config($quiet=FALSE)
 {
 
-   // I don't think we should try to load the default/sample
+   // I don't think we should try to load the default/example
    // file; this plugin has too many system-specific and/or
    // sensitive aspects to try to make a misconfigured plugin work.
    //
-   if (!@include_once(SM_PATH . 'plugins/squirrel_logger/config.php'))
-   {
-      if ($quiet)
-         return FALSE;
+   if (!@include_once(SM_PATH . 'config/config_squirrel_logger.php'))
+      if (!@include_once(SM_PATH . 'plugins/squirrel_logger/config.php'))
+      {
+         if ($quiet)
+            return FALSE;
 
-      echo 'ERROR: can\'t load squirrel_logger config file';
-      exit(1);
-   }
+         echo 'ERROR: can\'t load squirrel_logger config file';
+         exit(1);
+      }
 
    return TRUE;
 
@@ -270,6 +271,8 @@ function sl_monitor_present_msgs_do($args)
    $toList = array();
    $ccList = array();
    $bccList = array();
+   $replyToList = array();
+   $fromList = array();
 
    foreach ($message->rfc822_header->to as $recip)
       $toList[] = $recip->mailbox . $delimiter . $recip->host;
@@ -277,6 +280,10 @@ function sl_monitor_present_msgs_do($args)
       $ccList[] = $recip->mailbox . $delimiter . $recip->host;
    foreach ($message->rfc822_header->bcc as $recip)
       $bccList[] = $recip->mailbox . $delimiter . $recip->host;
+   foreach ($message->rfc822_header->reply_to as $sender)
+      $replyToList[] = $sender->mailbox . $delimiter . $sender->host;
+   foreach ($message->rfc822_header->from as $sender)
+      $fromList[] = $sender->mailbox . $delimiter . $sender->host;
 
 
    // too many recipients?  log it and possibly send alert
@@ -287,24 +294,34 @@ function sl_monitor_present_msgs_do($args)
 
       global $username, $sl_log_mass_mailing_show_recipients, 
              $sl_log_mass_mailing_show_message_body, $body,
+             $sl_log_mass_mailing_show_subject,
+             $sl_log_mass_mailing_show_from,
+             $sl_log_mass_mailing_show_reply_to,
              $sl_dateformat, $sl_namelookups, $subject;
       $msg = 'Total ' . $total_recips . ' recipients';
 
 
+      $address_delim = ', ';
+
+
       if ($sl_log_mass_mailing_show_recipients)
       {
-         $address_delim = ', ';
-
          $msg .= ' (TO: ' . implode($address_delim, $toList) . ')';
          $msg .= ' (CC: ' . implode($address_delim, $ccList) . ')';
          $msg .= ' (BCC: ' . implode($address_delim, $bccList) . ')';
       }
 
-      if ($sl_log_mass_mailing_show_message_body)
-      {
+      if ($sl_log_mass_mailing_show_from)
+         $msg .= ' (FROM: ' . implode($address_delim, $fromList) . ')';
+
+      if ($sl_log_mass_mailing_show_reply_to)
+         $msg .= ' (REPLY-TO: ' . implode($address_delim, $replyToList) . ')';
+
+      if ($sl_log_mass_mailing_show_subject)
          $msg .= ' (SUBJECT: ' . $subject . ')';
+
+      if ($sl_log_mass_mailing_show_message_body)
          $msg .= ' (BODY: ' . $body . ')';
-      }
 
 
       sl_logit('MASS_MAILING', $msg);
@@ -331,7 +348,9 @@ function sl_monitor_sent_msgs_do($args)
 
 
    global $domain, $only_log_domains, $skip_domains,
-          $sl_log_events,
+          $sl_log_events, $sl_log_outgoing_messages_show_from,
+          $sl_log_outgoing_messages_show_reply_to,
+          $sl_log_outgoing_messages_show_subject,
           $sl_log_outgoing_messages_show_recipients,
           $sl_log_outgoing_messages_show_message_body;
    sl_get_config();
@@ -354,6 +373,8 @@ function sl_monitor_sent_msgs_do($args)
    $toList = array();
    $ccList = array();
    $bccList = array();
+   $replyToList = array();
+   $fromList = array();
 
    foreach ($message->rfc822_header->to as $recip)
       $toList[] = $recip->mailbox . $delimiter . $recip->host;
@@ -361,6 +382,10 @@ function sl_monitor_sent_msgs_do($args)
       $ccList[] = $recip->mailbox . $delimiter . $recip->host;
    foreach ($message->rfc822_header->bcc as $recip)
       $bccList[] = $recip->mailbox . $delimiter . $recip->host;
+   foreach ($message->rfc822_header->reply_to as $sender)
+      $replyToList[] = $sender->mailbox . $delimiter . $sender->host;
+   foreach ($message->rfc822_header->from as $sender)
+      $fromList[] = $sender->mailbox . $delimiter . $sender->host;
 
 
    // have to remove < and > because otherwise the message ID
@@ -378,23 +403,30 @@ function sl_monitor_sent_msgs_do($args)
    }
 
 
+   $address_delim = ', ';
+
+
    if ($sl_log_outgoing_messages_show_recipients)
    {
-      $address_delim = ', ';
-
       $msg .= ' (TO: ' . implode($address_delim, $toList) . ')';
       $msg .= ' (CC: ' . implode($address_delim, $ccList) . ')';
       $msg .= ' (BCC: ' . implode($address_delim, $bccList) . ')';
    }
 
+   if ($sl_log_outgoing_messages_show_from)
+      $msg .= ' (FROM: ' . implode($address_delim, $fromList) . ')';
+
+   if ($sl_log_outgoing_messages_show_reply_to)
+      $msg .= ' (REPLY-TO: ' . implode($address_delim, $replyToList) . ')';
+
 global $body, $subject;
-   if ($sl_log_outgoing_messages_show_message_body)
-   {
+   if ($sl_log_outgoing_messages_show_subject)
       $msg .= ' (SUBJECT: ' . $subject . ')';
       ///$msg .= ' (SUBJECT: ' . $message->subject . ')';
+
+   if ($sl_log_outgoing_messages_show_message_body)
       $msg .= ' (BODY: ' . $body . ')';
       ///$msg .= ' (BODY: ' . $message->body_part . ')';
-   }
 
 
    sl_logit('OUTGOING_MAIL', $msg);
